@@ -147,12 +147,14 @@ class Onglets(wx.Notebook):
         subprocess.Popen(["bash", Variables.playonlinux_rep+"/configurations/configurators/"+self.s_title])
 
     def install_package(self, event):
-        selectedPackage = self.packageList.getPackageFromName(self.Menu.GetItemText(self.Menu.GetSelection()))
+        selectedPackageName = self.Menu.GetItemText(self.Menu.GetSelection())
+        if selectedPackageName:
+            selectedPackage = self.packageList.getPackageFromName(selectedPackageName)
 
-        if(self.s_isPrefix == False):
-            subprocess.Popen(["bash", Variables.playonlinux_env+"/bash/installpolpackages", self.s_title.encode('utf-8','replace'), selectedPackage])
-        else:
-            subprocess.Popen(["bash", Variables.playonlinux_env+"/bash/installpolpackages", "--prefix", self.s_prefix.encode('utf-8','replace'), selectedPackage])
+            if self.s_isPrefix == False:
+                subprocess.Popen(["bash", Variables.playonlinux_env+"/bash/installpolpackages", self.s_title.encode('utf-8','replace'), selectedPackage])
+            else:
+                subprocess.Popen(["bash", Variables.playonlinux_env+"/bash/installpolpackages", "--prefix", self.s_prefix.encode('utf-8','replace'), selectedPackage])
 
     def AddGeneralChamp(self, title, shortname, value, num):
         self.general_elements[shortname+"_text"] = wx.StaticText(self.panelGeneral, -1, title,pos=(15,19+num*40))
@@ -331,14 +333,22 @@ class Onglets(wx.Notebook):
                 self.i = self.i+1
                 
         self.PackageButton = wx.Button(self.panelPackages, 98, _("Install"), pos=(20+530-150,345), size=(150,30))
+        self.PackageButton.Disable()
 
-
+        wx.EVT_TREE_SEL_CHANGED(self, 99, self.package_selected)
         wx.EVT_TREE_ITEM_ACTIVATED(self, 99, self.install_package)
         wx.EVT_BUTTON(self, 98, self.install_package)
 
 
         self.AddPage(self.panelPackages, nom)
 
+    def package_selected(self, event):
+        selectedPackageName = self.Menu.GetItemText(self.Menu.GetSelection())
+        if selectedPackageName:
+            self.PackageButton.Enable()
+        else:
+            self.PackageButton.Disable()
+
     def change_Direct3D_settings(self, param):
         if(self.s_isPrefix == False):
             subprocess.Popen(["bash", Variables.playonlinux_env+"/bash/POL_Command", self.s_title.encode('utf-8','replace'), "POL_Wine_Direct3D", param, self.display_elements[param].GetValue().encode('utf-8','replace')])
@@ -651,7 +661,7 @@ class Onglets(wx.Notebook):
 
 class MainWindow(wx.Frame):
     def __init__(self,parent,id,title,shortcut, isPrefix = False):
-        wx.Frame.__init__(self, parent, -1, title, size = (800, 450+Variables.windows_add_size), style = wx.CLOSE_BOX | wx.CAPTION | wx.MINIMIZE_BOX)
+        wx.Frame.__init__(self, parent, -1, title, size = (800, 455+Variables.windows_add_size), style = wx.CLOSE_BOX | wx.CAPTION | wx.MINIMIZE_BOX)
         self.SetIcon(wx.Icon(Variables.playonlinux_env+"/etc/playonlinux.png", wx.BITMAP_TYPE_ANY))
         self.SetTitle(_('{0} configuration').format(os.environ["APPLICATION_TITLE"]))
         #self.panelFenp = wx.Panel(self, -1)
@@ -683,8 +693,8 @@ class MainWindow(wx.Frame):
             self.AddPrefix = wx.Button(self.control_game, 1001, _("New"), pos=(0,-8),size=(93,30))
             self.DelPrefix = wx.Button(self.control_game, 1002, _("Remove"), pos=(98,-8), size=(93,30))
         else:
-            self.AddPrefix = wx.Button(self.control_game, 1001, _("New"), pos=(0,0),size=(95,30))
-            self.DelPrefix = wx.Button(self.control_game, 1002, _("Remove"), pos=(100,0), size=(95,30))
+            self.AddPrefix = wx.Button(self.control_game, 1001, _("New"), pos=(0,0),size=(95,25))
+            self.DelPrefix = wx.Button(self.control_game, 1002, _("Remove"), pos=(100,0), size=(95,25))
 
         wx.EVT_BUTTON(self, 1001, self.NewPrefix)
         wx.EVT_BUTTON(self, 1002, self.DeletePrefix)
